@@ -3,4 +3,5 @@ utils::globalVariables(c('team', 'more', 'rec', 'seed', 'barthag','auto_prob','b
                          'X44','X17','X20','X43','fgm','fga','fg_pct','ppg','mpg','adj_o','adj_d','adj_t',
                          'pake', 'coach','result','score','points','opp_points','opp_conf','loc','lead_diff',
                          'V3', '.', 'ast', 'away', 'blk', 'fta', 'ftm', 'games', 'home', 'key', 'pf', 'pts',
-                         'stl', 'team1', 'team2', 'to', 'tpa', 'tpm', 'value', 'where', 'ts'))
+                         'stl', 'team1', 'team2', 'to', 'tpa', 'tpm', 'value', 'where', 'ts', 'num', 'abrev',
+                         'player', 'is_installed'))
