@@ -1,5 +1,5 @@
 test_that("throws error for season before 2008", {
-  expect_error(bart_coach_change(2007), 'valid year')
+  expect_error(bart_coach_change(2007), 'or later')
 })
 
 test_that('throws error for more than one space in coach name', {
